/** I N C L U D E S **********************************************************/
#include <p18cxxx.h>
#include "system\typedefs.h"

#include "system\usb\usb.h"

#include "io_cfg.h"             // I/O pin mapping
#include "user.h"
#include "delays.h"

/** V A R I A B L E S ********************************************************/
#pragma udata
char Buffer[64];

/** P R I V A T E  P R O T O T Y P E S ***************************************/
void Activeacd(void);
void Desactiveacd(void);
void getacd(int port, int config);
void setdefaultacd(void);
/** D E C L A R A T I O N S **************************************************/
#pragma code
void UserInit(void)
{
// on met configure tout en entre

	TRISA = 0b11111111;
	TRISB = 0b11111000;
	TRISC = 0b00000000;   // rc1 et rc2 a zero en sortie
	TRISD = 0b00000000;
	TRISE = 0b11111111;

	CCPR1 = 255; // parametrage de la periode on met le maximum pour avoir toute la resolution
	CCPR2 = 255;

	T2CON = 0b00000100; // regle timer 2 prescale 1 et enable

    //CONFIG3H.CCP2MX=1; 	//	CCP2MX = 1;			// selection CCP2 sur RC2 pins 17 p286
	CCP1CON = 0b00001100;	// configuration du mode PWM 1
	CCP2CON = 0b00001100;   // configuration du mode PWM 2
	
}//end UserInit



void Activeacd(void)
{
		/* 12 TAD FOSC/32 */
		// dans ADCON2 on charge la configuration des timer cf. 261 du datasheet 12 tad temps acquisition 32fosc temps de conversion
		ADCON2=42;

		/* AN0-15, VREF */
		// dans ADCON1 on les tension de ref et les pins utilises cf p260 du data sheet VDD et VSS comme ref et les 13 pins
		ADCON1 = 0b000000000; // on fixe les ref et on active les voies ana
		//ADCON1 = 0b00001011;
		/* Turn on the ADC */
		ADCON0bits.ADON = 1;
		//ADCON0bits.CHS3 = 0;
		//ADCON0bits.CHS2 = 0;
}

void Desactiveacd(void)
{
		/* 12 TAD FOSC/32 */
		// dans ADCON2 on charge la configuration des timer cf. 261 du datasheet 12 tad temps acquisition 32fosc temps de conversion
		ADCON2=42;

		/* AN0-15, VREF */
		// dans ADCON1 on les tension de ref et les pins utilises cf p260 du data sheet VDD et VSS comme ref et les 13 pins
		ADCON1 = 0b000001111; // on fixe les ref et on desactive les voies ana 
		//ADCON1 = 0b00001011;
		/* Turn on the ADC */
		ADCON0bits.ADON = 0;
		//ADCON0bits.CHS3 = 0;
		//ADCON0bits.CHS2 = 0;
}

void setdefaultacd(void)
{
}

void getacd(int port, int config)
{
	if (config) setdefaultacd(); // si c'est une demande de conf on charge la config
// FOSC/32 clock select
	switch (port) {// on selectionne la pins d'acquisition
		case 9 : {ADCON0bits.CHS3=1;ADCON0bits.CHS2=0;ADCON0bits.CHS1=0;ADCON0bits.CHS0=1;}   break;
		case 7 : {ADCON0bits.CHS3=0;ADCON0bits.CHS2=1;ADCON0bits.CHS1=1;ADCON0bits.CHS0=1;}   break;
		}
	ADCON0bits.GO = 1;// on lance l'acquisition
	while (ADCON0bits.GO); // on attend la fin de l'acquisition
}
// *****************************************************************************/
void ProcessIO(void)
{   
	int i;
	static pressed=0;
	static demande=0;

   if (HIDRxReport(Buffer,PacketSize ) > 0) // USB receive buffer has data
    
	{	// cas de l'ecriture des sortie PWM
		if (Buffer[0]==4)
		{	
			CCPR1L = Buffer[1];
			CCP1CON=CCP1CON | (Buffer[2]<< 4); // 0000 00xx devient 00xx 0000 puis on fait un OU logique 
			CCPR2L = Buffer[3];
			CCP2CON=CCP2CON | (Buffer[4]<< 4);
			
		}
		// cas de la lecture des Inputs TOR
		if (Buffer[0]==0)
		{	
			demande=1;
			Buffer[1]=PORTAbits.RA0;
			Buffer[2]=PORTAbits.RA1;
			Buffer[3]=PORTAbits.RA2;
			Buffer[4]=PORTAbits.RA3;
			Buffer[5]=PORTAbits.RA4;
			Buffer[6]=PORTEbits.RE1;
			Buffer[7]=PORTAbits.RA5;
			Buffer[8]=PORTEbits.RE0;
        	while (demande==1)
			{
			if(!mHIDTxIsBusy()) {                 // blocking
        	HIDTxReport(Buffer, PacketSize );   // transmit packet
			demande=0;}
			}
		}
		// cas de l'ecriture des sorties TOR
		if (Buffer[0]==1)
		{
			PORTBbits.RB2=Buffer[1];
			PORTBbits.RB0=Buffer[2];
			PORTBbits.RB1=Buffer[3];
			PORTDbits.RD7=Buffer[4];
			PORTDbits.RD6=Buffer[5];
			PORTDbits.RD3=Buffer[6];
			PORTDbits.RD2=Buffer[7];
		}	
		// cas d'une lecture d'entree ANA
		if (Buffer[0]==3)
		{	
			demande=1;
			Activeacd();	
			if (Buffer[1]==0) {
				getacd(9,1);}
			if (Buffer[1]==1) {
				getacd(7,1);}  
			Desactiveacd();
			Buffer[2]=ADRESH;
			Buffer[3]=ADRESL;
        	while (demande==1)
			{
			if(!mHIDTxIsBusy()) {                 // blocking
        	HIDTxReport(Buffer, PacketSize );   // transmit packet
			demande=0;}
			}
		}
	}	
}//end ProcessIO
